@@ -6,12 +6,17 @@ use std::collections::HashMap;
 
 #[test]
 fn command_default_aliases() {
+    #[derive(Clone)]
     struct InnerCommand {}
 
     impl Command for InnerCommand {
         fn name(&self) -> String {
             "".to_string()
         }
+
+        fn clone_and_box(&self) -> Box<dyn Command> {
+            Box::new((*self).clone())
+        }
     }
 
     let command = InnerCommand {};
@@ -22,12 +27,17 @@ fn command_default_aliases() {
 
 #[test]
 fn command_default_help() {
+    #[derive(Clone)]
     struct InnerCommand {}
 
     impl Command for InnerCommand {
         fn name(&self) -> String {
             "".to_string()
         }
+
+        fn clone_and_box(&self) -> Box<dyn Command> {
+            Box::new((*self).clone())
+        }
     }
 
     let command = InnerCommand {};
@@ -38,12 +48,17 @@ fn command_default_help() {
 
 #[test]
 fn command_default_run() {
+    #[derive(Clone)]
     struct InnerCommand {}
 
     impl Command for InnerCommand {
         fn name(&self) -> String {
             "".to_string()
         }
+
+        fn clone_and_box(&self) -> Box<dyn Command> {
+            Box::new((*self).clone())
+        }
     }
 
     let command = InnerCommand {};
@@ -54,12 +69,17 @@ fn command_default_run() {
 
 #[test]
 fn command_default_run_with_context() {
+    #[derive(Clone)]
     struct InnerCommand {}
 
     impl Command for InnerCommand {
         fn name(&self) -> String {
             "".to_string()
         }
+
+        fn clone_and_box(&self) -> Box<dyn Command> {
+            Box::new((*self).clone())
+        }
     }
 
     let mut context = Context::new();
